
#include <stdio.h>
#include <fcntl.h>
#include <glib.h>
#include <sys/types.h>
#include <dirent.h>
#include "libfile.h"
#include "midi_xfer.h"

int main(int argc, char *argv[])
{
    libfile_t *file;
    midi_context_t *midi_context;
    char *device;

    if (argc < 2)
    {
        fprintf(stderr, "%s file.lib\n", argv[0]);
        exit(1);
    }
    file = libfile_new(argv[1]);

    if (!file)
    {
        fprintf(stderr, "Reading %s failed\n", argv[1]);
        exit(1);
    }

    libfile_print(file);

    device = midi_find_device();
    if (!device) 
    {
        fprintf (stderr, "No MIDI device found!\n");
        exit(1);
    }

    printf ("MIDI device: %s\n", device); 

    midi_context = midi_open(device);
    if (midi_context)
    { 
        midi_send_params(midi_context, &file->lent.params);
        midi_close(midi_context);
    }

    g_free(device);

    libfile_destroy(file);
    return TRUE;
}
